nlsq package
=============

Submodules
----------

.. toctree::
   :maxdepth: 4

   nlsq.minpack
   nlsq.least_squares
   nlsq.trf
   nlsq.loss_functions
   nlsq.common_jax
   nlsq.common_scipy
   nlsq.caching
   nlsq.config
   nlsq.logging
   nlsq.optimizer_base

Module contents
---------------

.. automodule:: nlsq
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: StreamingConfig, MemoryConfig, LargeDatasetConfig
